@@ -13,6 +13,8 @@ from antgo.dataflow.recorder import *
 from antgo.crowdsource.demo_server import *
 from antgo.utils import logger
 from antvis.client.httprpc import *
+import multiprocessing
+
 try:
     import queue
 except:
@@ -33,14 +35,37 @@ class AntDemo(AntBase):
     self.ant_task_config = ant_task_config
 
     self.html_template = kwargs.get('html_template', None)
-    self.demo_port = kwargs.get('port', None)
+    self.demo_port = self.context.params.system.port
     self.demo_port = int(self.demo_port) if self.demo_port is not None else None
+
     # self.support_user_upload = kwargs.get('support_user_upload', False)
     # self.support_user_input = kwargs.get('support_user_input', False)
     # self.support_user_interaction = kwargs.get('support_user_interaction', False)
     # self.support_user_constraint = kwargs.get('support_user_constraint', None)
     self.context.devices = [int(d) for d in kwargs.get('devices', '').split(',') if d != '']
 
+    self._running_dataset = None
+    self._running_task = None
+
+  @property
+  def running_dataset(self):
+    return self._running_dataset
+
+  @property
+  def running_task(self):
+    return self._running_task
+
+  def ping_until_ok(self):
+    while True:
+      content = self.rpc.ping.get()
+      if content['status'] != 'ERROR':
+          break
+      # 暂停5秒钟，再进行尝试
+      time.sleep(5)
+
+  def wait_until_stop(self):
+    self.p.join()
+
   def start(self):
     # 1.step loading demo task
     running_ant_task = None
@@ -79,14 +104,13 @@ class AntDemo(AntBase):
       running_ant_task = custom_task
 
     assert (running_ant_task is not None)
+    self._running_task = running_ant_task
 
     # 2.step 注册实验
     experiment_uuid = self.context.experiment_uuid
     # 3.step 配置数据传输管道
-    dataset_queue = queue.Queue()
-
-    demo_dataset = QueueDataset(dataset_queue)
-    demo_dataset._force_inputs_dirty()
+    self._running_dataset = QueueDataset(multiprocessing.Queue())
+    self._running_dataset._force_inputs_dirty()
 
     # 3.step 配置dump路径
     infer_dump_dir = os.path.join(self.ant_dump_dir, experiment_uuid, 'inference')
@@ -104,12 +128,12 @@ class AntDemo(AntBase):
     logger.info('Demo prepare using port %d.'%self.demo_port)
 
     # 后台api调用
-    self.rpc = HttpRpc("v1", "api", "127.0.0.1", self.demo_port)
+    self.rpc = HttpRpc("v1", "antgo/api", "127.0.0.1", self.demo_port)
 
     demo_name = running_ant_task.task_name
     demo_type = running_ant_task.task_type
     demo_config = {
-      'interaction':{
+      'interaction': {
         'support_user_upload': True,
         'support_user_input': True,
         'support_user_interaction': False,
@@ -123,57 +147,66 @@ class AntDemo(AntBase):
 
     request_waiting_time = 30
     if self.context.params.demo is not None:
-      if 'support_user_upload' in self.context.params.demo:
-        demo_config['interaction']['support_user_upload'] = self.context.params.demo['support_user_upload']
+      if 'support_user_upload' in self.context.params.demo.keys():
+        demo_config['interaction']['support_user_upload'] = self.context.params.demo.support_user_upload
 
-      if 'support_user_input' in self.context.params.demo:
-        demo_config['interaction']['support_user_input'] = self.context.params.demo['support_user_input']
+      if 'support_user_input' in self.context.params.demo.keys():
+        demo_config['interaction']['support_user_input'] = self.context.params.demo.support_user_input
 
-      if 'support_user_interaction' in self.context.params.demo:
-        demo_config['interaction']['support_user_interaction'] = self.context.params.demo['support_user_interaction']
+      if 'support_user_interaction' in self.context.params.demo.keys():
+        demo_config['interaction']['support_user_interaction'] = self.context.params.demo.support_user_interaction
 
-      if 'support_user_constraint' in self.context.params.demo:
-        demo_config['interaction']['support_user_constraint'] = self.context.params.demo['support_user_constraint']
+      if 'support_user_constraint' in self.context.params.demo.keys():
+        demo_config['interaction']['support_user_constraint'] = self.context.params.demo.support_user_constraint
 
-      if 'request_waiting_time' in self.context.params.demo:
-        request_waiting_time = self.context.params.demo['request_waiting_time']
+      if 'request_waiting_time' in self.context.params.demo.keys():
+        request_waiting_time = self.context.params.demo.request_waiting_time
 
-    # 5.step 启动后台线程运行预测过程
-    def _run_infer_process():
-      # prepare ablation blocks
-      logger.info('Prepare model ablation blocks.')
-      ablation_blocks = getattr(self.ant_context.params, 'ablation', [])
-      if ablation_blocks is None:
-        ablation_blocks = []
-      for b in ablation_blocks:
-        self.ant_context.deactivate_block(b)
+    # 在独立进程中启动webserver
+    self.p = multiprocessing.Process(
+      target=demo_server_start,
+      args=(
+        demo_name,
+        demo_type,
+        demo_config,
+        self._running_dataset.queue,
+        request_waiting_time)
+    )
+    self.p.start()
+
+    # 5.step 启动运行预测过程
+    # prepare ablation blocks
+    logger.info('Prepare model ablation blocks.')
+    ablation_blocks = getattr(self.ant_context.params, 'ablation', [])
+    if ablation_blocks is None:
+      ablation_blocks = []
+    for b in ablation_blocks:
+      self.ant_context.deactivate_block(b)
+
+    # infer
+    try:
+      def _callback_func(data):
+        record_content = {
+          'experiment_uuid': experiment_uuid,
+          'data': data,
+          'id': data[0][0]['id'] if len(data) > 0 else 'unkown',
+        }
+        for data_group in record_content['data']:
+          for item in data_group:
+            if item['type'] in ['IMAGE', 'VIDEO', 'FILE']:
+              item['data'] = '%s/record/%s' % (infer_dump_dir, item['data'])
+
+        self.rpc.demo.response.post(response=json.dumps(record_content))
+
+      self.context.recorder = LocalRecorderNodeV2(_callback_func)
+      if self.context.is_interact_mode:
+        self.context.recorder.dump_dir = os.path.join(infer_dump_dir, 'record')
+        if not os.path.exists(self.context.recorder.dump_dir):
+          os.makedirs(self.context.recorder.dump_dir)
+        return
 
-      # infer
       logger.info('Running inference process.')
-      try:
-        def _callback_func(data):
-            id = demo_dataset.now()['id'] if 'id' in demo_dataset.now() else ''
-            record_content = {
-                        'experiment_uuid': experiment_uuid, 
-                        'data': data,
-                        'id': id
-                    }
-            for data_group in record_content['data']:
-              for item in data_group:
-                  if item['type'] in ['IMAGE', 'VIDEO', 'FILE']:
-                      item['data'] = '%s/record/%s'%(infer_dump_dir, item['data'])
-                
-            self.rpc.response.post(response=json.dumps(record_content))
-                    
-        self.context.recorder = LocalRecorderNodeV2(_callback_func)
-        self.context.call_infer_process(demo_dataset, dump_dir=infer_dump_dir)
-      except Exception as e:
-        print(e)
-        traceback.print_exc()
-
-    process = threading.Thread(target=_run_infer_process)
-    process.daemon = True
-    process.start()
-
-    # 6.step 启动web服务
-    demo_server_start(demo_name,demo_type,demo_config,os.getpid(),dataset_queue, request_waiting_time)
+      self.context.call_infer_process(self.running_dataset, dump_dir=infer_dump_dir)
+    except Exception as e:
+      print(e)
+      traceback.print_exc()
\ No newline at end of file
