@@ -12,6 +12,7 @@ from antgo.dataflow.dataset import *
 from antgo.framework.helper.fileio.file_client import *
 import cv2
 import time
+from filelock import FileLock
 
 
 __all__ = ['Cityscape']
@@ -19,23 +20,13 @@ class Cityscape(Dataset):
     def __init__(self, train_or_test, dir=None, ext_params=None):
         super(Cityscape, self).__init__(train_or_test, dir, ext_params=ext_params)
         assert(train_or_test in ['train', 'val', 'test'])
-        if os.environ.get('LOCAL_RANK', 0) == 0:
+        lock = FileLock('DATASET.lock')
+        with lock:
             if not os.path.exists(os.path.join(self.dir, 'cityscapes')):
                 # 数据集不存在，需要重新下载，并创建标记                
                 ali = AliBackend()
                 ali.download('ali:///dataset/cityscapes/cityscapes.tar', self.dir)
                 os.system(f'cd {self.dir} && tar -xf cityscapes.tar')
-                os.system('touch DATASET_IS_READY')
-            else:
-                # 数据集存在，创建标记
-                if not os.path.exists('DATASET_IS_READY'):
-                    os.system('touch DATASET_IS_READY')  
-        else:
-            while True:
-                # 等待直到存在指定文件
-                if os.path.exists('DATASET_IS_READY'):
-                    break
-                time.sleep(5)
 
         self._image_file_list = []
         self._annotation_file_list = []
