@@ -19,6 +19,7 @@ from antgo.dataflow.dataset.dataset import *
 from antgo.utils import mask as maskUtils
 from antgo.utils.fs import maybe_here_match_format
 from antgo.framework.helper.fileio.file_client import *
+from filelock import FileLock
 
 
 __all__ = ['COCO2017']
@@ -389,7 +390,8 @@ class COCO2017(Dataset):
     assert (self.task_type in ['SEGMENTATION', 'OBJECT-DETECTION', 'INSTANCE-SEGMENTATION', 'LANDMARK'])
 
     if not os.path.exists(os.path.join(self.dir , 'annotations')):
-      if os.environ.get('LOCAL_RANK', 0) == 0:
+      lock = FileLock('DATASET.lock')
+      with lock:
         if not os.path.exists(os.path.join(self.dir, 'COCO')):
           # 数据集不存在，需要重新下载，并创建标记
           ali = AliBackend()
@@ -397,17 +399,6 @@ class COCO2017(Dataset):
           assert(os.path.exists(os.path.join(self.dir, 'COCO.tar')))
           # 解压
           os.system(f'cd {self.dir} && tar -xf COCO.tar')
-          os.system('touch DATASET_IS_READY')
-        else:
-          # 数据集存在，创建标记
-          if not os.path.exists('DATASET_IS_READY'):
-            os.system('touch DATASET_IS_READY')
-      else:
-        while True:
-          # 等待直到存在指定文件
-          if os.path.exists('DATASET_IS_READY'):
-            break
-          time.sleep(5)
 
       # 修改数据目录
       self.dir = os.path.join(self.dir, 'COCO')
@@ -533,6 +524,10 @@ class COCO2017(Dataset):
             continue
         if obj['category_id'] not in self.cat_ids:
             continue
+        if obj['iscrowd'] == 1:
+          # 去除群体标注
+          continue
+
         # 目标框
         boxes.append([x, y, x + w, y + h])
         # 目标类别
@@ -543,7 +538,8 @@ class COCO2017(Dataset):
       img_annotation['labels'] = np.array(category_id)
       img = imread(os.path.join(self.dir, '%s2017'%self.train_or_test, img_obj['file_name']))
       img_annotation['image_meta'] = {
-        'image_shape': (img.shape[0], img.shape[1])
+        'image_shape': (img.shape[0], img.shape[1]),
+        'image_file': os.path.join(self.dir, '%s2017'%self.train_or_test, img_obj['file_name'])
       }
 
       return (img, img_annotation)
@@ -566,7 +562,8 @@ class COCO2017(Dataset):
       img_annotation = {
         'segments': segmentation_map,
         'image_meta': {
-          'image_shape': (img.shape[0], img.shape[1])
+          'image_shape': (img.shape[0], img.shape[1]),
+          'image_file': os.path.join(self.dir, '%s2017'%self.train_or_test, img_obj['file_name'])
         }
       }
       return (img, img_annotation)
@@ -615,7 +612,8 @@ class COCO2017(Dataset):
         'bboxes': np.array(boxes),
         'labels': np.array(labels),
         'image_meta': {
-          'image_shape': (img.shape[0], img.shape[1])
+          'image_shape': (img.shape[0], img.shape[1]),
+          'image_file': os.path.join(self.dir, '%s2017'%self.train_or_test, img_obj['file_name'])
         }
       }
       return (img, img_annotation)
