@@ -13,6 +13,7 @@ import numpy as np
 import cv2
 import time
 from antgo.framework.helper.fileio.file_client import *
+from filelock import FileLock
 
 
 __all__ = ['FLIC']
@@ -21,23 +22,13 @@ class FLIC(Dataset):
     super(FLIC, self).__init__(train_or_test, dir, ext_params)
     
     if not os.path.exists(os.path.join(self.dir, 'examples.mat')):
-      if os.environ.get('LOCAL_RANK', 0) == 0:
+      lock = FileLock('DATASET.lock')
+      with lock:
         if not os.path.exists(os.path.join(self.dir, 'FLIC-full')):
           # 数据集不存在，需要重新下载，并创建标记
           ali = AliBackend()
           ali.download('ali:///dataset/flic/FLIC-full.zip', self.dir)
           os.system(f'cd {self.dir} && unzip FLIC-full.zip')
-          os.system('touch DATASET_IS_READY')
-        else:
-          # 数据集存在，创建标记
-          if not os.path.exists('DATASET_IS_READY'):
-            os.system('touch DATASET_IS_READY')
-      else:
-        while True:
-          # 等待直到存在指定文件
-          if os.path.exists('DATASET_IS_READY'):
-            break
-          time.sleep(5)
 
       self.dir = os.path.join(self.dir, 'FLIC-full')
 
