@@ -12,7 +12,7 @@ from antgo.pipeline.functional.mixins.dataframe import DataFrameMixin
 from antgo.pipeline.hparam import param_scope, dynamic_dispatch
 from antgo.pipeline.functional.entity import EntityView
 from antgo.pipeline.functional.option import Option, Some
-
+from antgo.pipeline.functional.common.config import *
 
 class DataCollection(Iterable, DCMixins):
   """A pythonic computation and processing framework.
@@ -108,6 +108,9 @@ class DataCollection(Iterable, DCMixins):
         # pylint: disable=protected-access
         path = hp._name
         index = hp._index
+      
+      # 添加算子节点信息到全局配置
+      add_op_info(path, index, arg, kws)
       op = self.resolve(path, index, *arg, **kws)
       return self.map(op)
 
